Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(260)

Unified Diff: content/browser/fileapi/fileapi_message_filter.cc

Issue 10823273: Integrate external mount points to IsolatedContext (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: remove too strict DCHECK Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/fileapi/fileapi_message_filter.cc
diff --git a/content/browser/fileapi/fileapi_message_filter.cc b/content/browser/fileapi/fileapi_message_filter.cc
index da6581b5d4d5a24abe3222a91f9a8374afa1a445..ca59679e48f205890b20b70e3551ddf6c8336e09 100644
--- a/content/browser/fileapi/fileapi_message_filter.cc
+++ b/content/browser/fileapi/fileapi_message_filter.cc
@@ -755,10 +755,10 @@ bool FileAPIMessageFilter::HasPermissionsForFile(
ChildProcessSecurityPolicyImpl* policy =
ChildProcessSecurityPolicyImpl::GetInstance();
// Special handling for filesystems which have isolated filesystem_id.
// (See ChildProcessSecurityPolicy::GrantReadFileSystem for more
// details about access permission for isolated filesystem.)
- if (!url.filesystem_id().empty()) {
+ if (url.mount_type() == fileapi::kFileSystemMountTypeIsolated) {
// The root directory of the dragged filesystem is read-only.
if (url.type() == fileapi::kFileSystemTypeDragged && url.path().empty()) {
if (permissions != kReadFilePermissions) {
@@ -755,10 +755,10 @@ bool FileAPIMessageFilter::HasPermissionsForFile(
ChildProcessSecurityPolicyImpl* policy =
ChildProcessSecurityPolicyImpl::GetInstance();
- // Special handling for filesystems which have isolated filesystem_id.
+ // Special handling for filesystems whose mount type is isolated.
// (See ChildProcessSecurityPolicy::GrantReadFileSystem for more
// details about access permission for isolated filesystem.)
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_file_system_proxy.cc ('k') | webkit/chromeos/fileapi/cros_mount_point_provider.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698